pub enum CaPoolError {
NotACA,
NotSelfSigned,
NoIssuer,
}Expand description
A list of errors that can happen when working with a CA Pool
Variants
NotACA
Tried to add a non-CA cert to the CA pool
NotSelfSigned
Tried to add a non-self-signed cert to the CA pool (all CAs must be root certificates)
NoIssuer
Tried to look up a certificate that does not have an issuer field